@@ -435,14 +435,20 @@ class Page(Plugin):
 
     def boot_rp(self):
         """attempts to kexec a new kernel and falls back to a reboot"""
-        subprocess.call(['/etc/init.d/casper','stop'])
+
+        with open ('/proc/cmdline', 'r') as rfd:
+            noprompt = 'noprompt' in rfd.readline()
 
         if self.kexec and os.path.exists(CDROM_MOUNT + '/misc/kexec'):
             shutil.copy(CDROM_MOUNT + '/misc/kexec', '/tmp')
 
-        #Set up a listen for udisks to let us know a usb device has left
-        bus = dbus.SystemBus()
-        bus.add_signal_receiver(reboot_machine, 'DeviceRemoved', 'org.freedesktop.UDisks')
+        #only cache casper if it's not going to ask the user to eject the media
+        if noprompt:
+            subprocess.call(['/etc/init.d/casper','stop'])
+
+            #Set up a listen for udisks to let us know a usb device has left
+            bus = dbus.SystemBus()
+            bus.add_signal_receiver(reboot_machine, 'DeviceRemoved', 'org.freedesktop.UDisks')
 
         if self.dual:
             self.ui.show_dual_dialog()
@@ -707,7 +713,7 @@ class Page(Plugin):
 
     def cancel_handler(self):
         """Called when we don't want to perform recovery'"""
-        misc.execute_root('reboot','-n')
+        misc.execute_root('reboot')
 
     def handle_exception(self, e):
         self.debug(str(e))
@@ -928,7 +934,7 @@ def reboot_machine(objpath):
             syslog.syslog("unable to kexec")
 
     reboot_cmd = '/sbin/reboot'
-    reboot = misc.execute_root(reboot_cmd,'-n')
+    reboot = misc.execute_root(reboot_cmd)
     if reboot is False:
         raise RuntimeError, ("Reboot failed")
 
